# DataVizML

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Coverage Status](https://coveralls.io/repos/github/dibble07/datavizml/badge.svg?branch=main&kill_cache=1)](https://coveralls.io/github/dibble07/datavizml?branch=main&kill_cache=1)
[![Documentation Status](https://readthedocs.org/projects/datavizml/badge/?version=latest)](https://datavizml.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/datavizml.svg)](https://badge.fury.io/py/datavizml)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/datavizml)

``DataVizML`` is a high-level Object Orientated Python package which aims to provide an easy and intuitive way of exploring the distribution of a set of ML model features and their relationship to a proposed target

## Installation

It is recommended to install ``DataVizML`` using pip:
```
pip install datavizml
```

## Documentation

[Read the Docs](https://datavizml.readthedocs.io/en/latest/)

## Related reading

[Predictive Power Score (PPS)](https://github.com/8080labs/ppscore)